==> nextcloud-13.0.1.tgz: nextcloud/apps/gallery/.github/issue_template.md <==
<!--
This is the issue tracker of Gallery.

Thank you for taking the time to:
* report an issue you've experienced or
* to submit a feature request.

To make it easier for us to help you, please fill in as much information as possible in
one of the forms below.

Please choose between the "Bug report" and the "Feature request" form and delete the content of the other one
-->

## Bug report

### Steps to reproduce

1.
1.
1.

### Expected behaviour
<!--
Tell us what should happen
Tip: You can leave alone text surrounded by special markers such as this one, they're invisible
-->

### Actual behaviour
<!--
Tell us what happens instead
-->


### Server configuration
<!--
You can use the Issue Template application to prefill most of the required information: https://apps.nextcloud.com/apps/issuetemplate
-->

**Operating system**:

**Web server:**

**Database:**

**PHP version:**

**cloud server:** Nextcloud or ownCloud

**cloud version:** (see admin page or version.php)

**Updated from an older installation or fresh install:**

**List of activated apps:**
<!--
If you have access to your command line run e.g.:
# sudo -u www-data php occ app:list`
from within your installation folder*
-->

<details>
<summary>App list</summary>

```
Paste the list of applications here
```

</details>

**Nextcloud configuration:**

```
If you have access to your command line run e.g.:
sudo -u www-data php occ config:list system
from within your Nextcloud installation folder

or

Insert your config.php content here
Make sure to remove all sensitive content such as passwords. (e.g. database password, passwordsalt, secret, smtp password, …)
```

<details>
<summary>Config report</summary>

```
Paste the config here
```

</details>

**Are you using external storage, if yes which one:** local folder, smb share, sftp, etc.

**Are you using encryption:** yes/no

**Are you using custom gallery.cnf config files:** yes/no

#### Web server error log

<details>
<summary>Web server error log</summary>

```
Insert your webserver log here
```
</details>

#### Cloud log
<!--
The log has the name owncloud.log or nextcloud.log and is found in the data folder
-->

<details>
<summary>Cloud log</summary>

```
Insert your cloud log here
```
</details>

### Client configuration

**Browser:**

**Operating system:**

#### Browser log
<!--
Press F12 in your browser and copy the relevant information from:

a) The javascript console log
b) The network log
c) etc.
-->

<details>
<summary>Browser log</summary>

```
Insert your browser log here
```

</details>

## Feature request

**User type**: Logged-in or public user

**User level**: Beginners, intermediate or advanced

### Description
<!--
Please try to give as much information as you can about your request
-->

### Benefit / value
<!--
Please explain how it could benefit users of the app, other apps or 3rd party services
-->

### Risk / caveats
<!--
Please explain the risks and caveats associated with this request
-->

### Sponsorship
<!--
This greatly accelerates the delivery of a feature
-->

**Are you a developer willing to implement this feature?**: yes/no

**Can you sponsor the development of this feature or do you know someone who can?**: yes/no

==> nextcloud-14.0.1.tgz: nextcloud/apps/gallery/.github/issue_template.md <==
<!--
This is the issue tracker of Gallery.

Thank you for taking the time to:
* report an issue you've experienced or
* to submit a feature request.

To make it easier for us to help you, please fill in as much information as possible in
one of the forms below.

Please choose between the "Bug report" and the "Feature request" form and delete the content of the other one
-->

# Bug report

## Steps to reproduce

1.
1.
1.

## Expected behaviour
<!--
Tell us what should happen
Tip: You can leave alone text surrounded by special markers such as this one, they're invisible
-->

## Actual behaviour
<!--
Tell us what happens instead
-->


## Server configuration
<!--
You can use the Issue Template application to prefill most of the required information: https://apps.nextcloud.com/apps/issuetemplate
-->

**Operating system**:

**Web server:**

**Database:**

**PHP version:**

### Nextcloud configuration

**Nextcloud version:** (see admin page or version.php)

**Updated from an older installation or fresh install:**

**List of activated apps:**
<!--
If you have access to your command line run e.g.:
# sudo -u www-data php occ app:list`
from within your installation folder*
-->

<details>
<summary>App list</summary>

```
Paste the list of applications here
```

</details>


**Nextcloud configuration:**
<!--
If you have access to your command line run e.g.:
sudo -u www-data php occ config:list system
from within your Nextcloud installation folder
or
Insert your config.php content here
Make sure to remove all sensitive content such as passwords. (e.g. database password, passwordsalt, secret, smtp password, …)
-->

<details>
<summary>Config.php</summary>
  
```
Paste the config here
```

</details>

**Are you using external storage, if yes which one:** local folder, smb share, sftp, etc.

**Are you using encryption:** yes/no

**Are you using custom gallery.cnf config files:** yes/no

### Web server error log

<details>
<summary>Web server error log</summary>

```
Insert your webserver log here
```
</details>

### Nextcloud log
<!--
The log has the name nextcloud.log and is found in the data folder
-->

<details>
<summary>Nextcloud log</summary>

```
Insert your Nextcloud log here
```
</details>

## Client configuration

**Browser:**

**Operating system:**

### Browser log
<!--
Press F12 in your browser and copy the relevant information from:

a) The javascript console log
b) The network log
c) etc.
-->

<details>
<summary>Browser log</summary>

```
Insert your browser log here
```

</details>

# Feature request

**User type**: Logged-in or public user

**User level**: Beginners, intermediate or advanced

## Description
<!--
Please try to give as much information as you can about your request
-->

## Benefit / value
<!--
Please explain how it could benefit users of the app, other apps or 3rd party services
-->

## Risk / caveats
<!--
Please explain the risks and caveats associated with this request
-->

## Sponsorship
<!--
This greatly accelerates the delivery of a feature
-->

**Are you a developer willing to implement this feature?**: yes/no

**Can you sponsor the development of this feature or do you know someone who can?**: yes/no
